partridge package
=================

Submodules
----------

partridge\.config module
------------------------

.. automodule:: partridge.config
    :members:
    :undoc-members:
    :show-inheritance:

partridge\.gtfs module
----------------------

.. automodule:: partridge.gtfs
    :members:
    :undoc-members:
    :show-inheritance:

partridge\.parsers module
-------------------------

.. automodule:: partridge.parsers
    :members:
    :undoc-members:
    :show-inheritance:

partridge\.utilities module
---------------------------

.. automodule:: partridge.utilities
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: partridge
    :members:
    :undoc-members:
    :show-inheritance:
